@@ -1,8 +1,8 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1001'; # VERSION
-# ABSTRACT: ...
-# PODNAME: ToHtmlPreBlock.pm
+our $VERSION = '0.1002'; # VERSION
+# ABSTRACT: A plugin that renders to html
+# PODNAME: Stenciller::Plugin::ToHtmlPreBlock
 
 class Stenciller::Plugin::ToHtmlPreBlock using Moose with Stenciller::Renderer {
 
@@ -53,11 +53,11 @@ __END__
 
 =head1 NAME
 
-ToHtmlPreBlock.pm - ...
+Stenciller::Plugin::ToHtmlPreBlock - A plugin that renders to html
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-15.
+Version 0.1002, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ Version 0.1001, released 2015-01-15.
 
 This plugin to L<Stenciller> places the C<before_input>, C<between> and C<after_output> regions in C<E<lt>pE<gt>> tags and the C<input> and C<output> regions inside C<E<lt>preE<gt>> tags.
 
-:splint classname Stenciller::Plugin::ToHtmlPreBlock
+
 
 =head1 SOURCE
 
