@@ -1,8 +1,8 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1001'; # VERSION
-# ABSTRACT: ...
-# PODNAME: ToUnparsedText.pm
+our $VERSION = '0.1002'; # VERSION
+# ABSTRACT: A plugin that just renders all the text
+# PODNAME: Stenciller::Plugin::ToUnparsedText
 
 class Stenciller::Plugin::ToUnparsedText using Moose with Stenciller::Renderer {
 
@@ -31,11 +31,11 @@ __END__
 
 =head1 NAME
 
-ToUnparsedText.pm - ...
+Stenciller::Plugin::ToUnparsedText - A plugin that just renders all the text
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-15.
+Version 0.1002, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ Version 0.1001, released 2015-01-15.
 
 This plugin to L<Stenciller> basically returns all text content of the stencils.
 
-:splint classname Stenciller::Plugin::ToUnparsedText
+
 
 =head1 SOURCE
 
