@@ -1,8 +1,8 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1001'; # VERSION
-# ABSTRACT: ...
-# PODNAME: Renderer.pm
+our $VERSION = '0.1002'; # VERSION
+# ABSTRACT: A role for plugins to consume
+# PODNAME: Stenciller::Renderer
 
 role Stenciller::Renderer using Moose {
 
@@ -25,11 +25,11 @@ __END__
 
 =head1 NAME
 
-Renderer.pm - ...
+Stenciller::Renderer - A role for plugins to consume
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-15.
+Version 0.1002, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ Version 0.1001, released 2015-01-15.
 
 This is the role that all L<Stenciller> plugins must consume. It requires a C<render> method to be implemented.
 
-:splint classname Stenciller::Renderer
+
 
 =head1 ATTRIBUTES
 
