@@ -3,11 +3,13 @@ use warnings;
 
 use Moops;
 
-our $VERSION = '0.1001'; # VERSION
-# PODNAME: Stenciller.pm
+our $VERSION = '0.1002'; # VERSION
+# PODNAME: Types::Stenciller
+# ABSTRACT: Types for Stenciller
+
 library Types::Stenciller
 
-extends Types::Standard, Types::TypeTiny, Types::Path::Tiny
+extends Types::Standard, Types::Path::Tiny
 
 declares Stencil, Renderer, Stenciller
 
@@ -28,11 +30,11 @@ __END__
 
 =head1 NAME
 
-Stenciller.pm
+Types::Stenciller - Types for Stenciller
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-15.
+Version 0.1002, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -40,20 +42,25 @@ Version 0.1001, released 2015-01-15.
 
 =head1 DESCRIPTION
 
-Defines a few types used in the C<Stenciller> namespace.
+Defines a couple of types used in the C<Stenciller> namespace.
+
 
-:splint classname Types::Stenciller
 
 =head1 TYPES
 
 =over 4
 
+=item *
 
+C<Stencil> is a L<Stenciller::Stencil>
+
+=item *
+
+C<Stenciller> is a L<Stenciller>
 
 =back
 
-* C<Stencil> is a L<Stenciller::Stencil>
-* C<Stenciller> is a L<Stenciller>
+It also inherits from L<Types::Standard> and L<Types::Path::Tiny>.
 
 =head1 SOURCE
 
